==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2PR/ts/Circle2PR_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Circle2PR</name>
    <message>
        <location filename="../Circle2PR.js" line="+65"/>
        <source>First point</source>
        <translation>第一点</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point</source>
        <translation>第二点</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Invalid radius</source>
        <translation>无效的半径</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>两点是相同的</translation>
    </message>
    <message>
        <location filename="../Circle2PR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>半径：</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Solution:</source>
        <translation>解决方案：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Center Left of Line P1 - P2</source>
        <translation>线P1-P2的中左部分</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Solution</source>
        <translation>解决方案</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Center Right of Line P1 - P2</source>
        <translation>线P1-P2的中右部分</translation>
    </message>
    <message>
        <location filename="../Circle2PRInit.js" line="+2"/>
        <source>&amp;2 Points and Radius</source>
        <translation>点和半径(&amp;2)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle from 2 points and radius</source>
        <translation>按2个点和半径画弧线</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Circle/Circle2PR/ts/Circle2PR_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Circle2PR</name>
    <message>
        <location filename="../Circle2PR.js" line="+65"/>
        <source>First point</source>
        <translation>第一点</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second point</source>
        <translation>第二点</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Invalid radius</source>
        <translation>无效的半径</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>The two points are identical</source>
        <translation>两点为同一点</translation>
    </message>
    <message>
        <location filename="../Circle2PR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>半径：</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Solution:</source>
        <translation>方案：</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Center Left of Line P1 - P2</source>
        <translation>线P1-P2的中间偏左</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Solution</source>
        <translation>方案</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Center Right of Line P1 - P2</source>
        <translation>线P1-P2的中间偏右</translation>
    </message>
    <message>
        <location filename="../Circle2PRInit.js" line="+2"/>
        <source>&amp;2 Points and Radius</source>
        <translation>2点和半径(&amp;2)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw circle from 2 points and radius</source>
        <translation>以2点和半径画圆</translation>
    </message>
</context>
</TS>
